@@ -28,6 +28,11 @@
 #'   data is present. Set to NA to hide the line. See [link_recomb()] to add
 #'   recombination rate data.
 #' @param legend_pos Position of legend. Set to `NULL` to hide legend.
+#' @param labels Character vector of SNP or genomic feature IDs to label. The
+#'   value "index" selects the highest point or index SNP as defined when
+#'   [locus()] is called. Set to `NULL` to remove all labels.
+#' @param ... Optional arguments passed to `geom_text_repel()` to configure
+#'   label drawing.
 #' @return Returns a ggplot2 plot.
 #' @details
 #' If recombination rate data is included in the locus object following a call
@@ -48,6 +53,7 @@
 #'  scale_fill_manual scale_color_manual aes guide_legend element_text
 #'  element_blank element_rect unit geom_hline scale_y_continuous sec_axis
 #'  geom_line
+#' @importFrom ggrepel geom_text_repel
 #' @importFrom dplyr bind_rows
 #' @importFrom rlang .data
 #' @importFrom zoo na.approx
@@ -69,7 +75,8 @@ gg_scatter <- function(loc,
                        LD_scheme = c('grey', 'royalblue', 'cyan2', 'green3', 
                                      'orange', 'red', 'purple'),
                        recomb_col = "blue",
-                       legend_pos = 'topleft') {
+                       legend_pos = 'topleft',
+                       labels = NULL, ...) {
   if (!inherits(loc, "locus")) stop("Object of class 'locus' required")
   if (is.null(loc$data)) stop("No data points, only gene tracks")
   data <- loc$data
@@ -86,7 +93,10 @@ gg_scatter <- function(loc,
       data$bg <- factor(data$bg, levels = 1:7)
       data <- data[order(data$bg), ]
       scheme <- rep_len(LD_scheme, 7)
-      if (is.null(index_snp)) scheme <- scheme[1:6]
+      if (is.null(index_snp)) {
+        scheme <- scheme[1:6]
+        data$bg <- factor(data$bg, levels = 1:6)
+      }
     } else {
       data$bg <- scheme[1]
       if (loc$yvar == "logP") data$bg[data[, loc$p] < pcutoff] <- scheme[2]
@@ -131,7 +141,19 @@ gg_scatter <- function(loc,
     data$recomb <- zoo::na.approx(data$recomb, data[, loc$pos], na.rm = FALSE)
   }
   data[, loc$pos] <- data[, loc$pos] / 1e6
-  
+
+  # add labels
+  if (!is.null(labels)) {
+    i <- grep("index", labels, ignore.case = TRUE)
+    if (i) labels[i] <- index_snp
+    text_label_ind <- match(labels, data[, loc$labs])
+    if (any(is.na(text_label_ind))) {
+      message("label ", paste(labels[is.na(text_label_ind)], collapse = ", "),
+              " not found")
+    }
+  }
+  df2 <- data[data[, loc$labs] == index_snp, ]
+
   if (!recomb) {
     # standard plot
     p <- ggplot(data, aes(x = .data[[loc$pos]], y = .data[[loc$yvar]],
@@ -142,6 +164,7 @@ gg_scatter <- function(loc,
                    colour = "grey", linetype = "dashed")
       }) +
       geom_point(shape = 21, size = size) +
+      geom_point(data = df2, shape = 23, size = size +0.3, show.legend = FALSE) +  # index SNP
       scale_fill_manual(breaks = levels(data$bg), values = scheme,
                         guide = guide_legend(reverse = TRUE),
                         labels = legend_labels, name = expression({r^2})) +
@@ -172,6 +195,11 @@ gg_scatter <- function(loc,
       }) +
       geom_point(aes(y = .data[[loc$yvar]], color = .data$col,
                      fill = .data$bg), shape = 21, size = size, na.rm = TRUE) +
+      # index SNP
+      geom_point(data = df2,
+                 aes(y = .data[[loc$yvar]], color = .data$col,
+                     fill = .data$bg), shape = 23, size = size +0.3, na.rm = TRUE,
+                 show.legend = FALSE) +
       scale_fill_manual(breaks = levels(data$bg), values = scheme,
                         guide = guide_legend(reverse = TRUE),
                         labels = legend_labels, name = expression({r^2})) +
@@ -196,6 +224,15 @@ gg_scatter <- function(loc,
       if (!xticks) theme(axis.text.x=element_blank(),
                          axis.ticks.x=element_blank())
   }
+
+  if (!is.null(labels)) {
+    p <- p +
+      geom_text_repel(data = data[text_label_ind, ],
+                      mapping = aes(x = .data[[loc$pos]], y = .data[[loc$yvar]],
+                                    label = .data[[loc$labs]]),
+                      point.size = size, ...)
+  }
+
   if (border | recomb) {
     p <- p + theme(panel.border = element_rect(colour = "black", fill = NA))
   }
